# frozen_string_literal: true

class MixedCaseMonkey < ActiveRecord::Base
  belongs_to :human
end
